The first subdataset 'cdr_seaice_conc' is the one you want, but also included are "cdr_seaice_conc_interp_spatial_flag", "cdr_seaice_conc_interp_temporal_flag", "cdr_seaice_conc_qa_flag", "cdr_seaice_conc_stdev", "raw_bt_seaice_conc", "raw_nt_seaice_conc" and "surface_type_mask"
seaice_cdr(date, hemisphere = c("south", "north"), vsi = TRUE)string with path to CDR sea ice netcdf file
I've had mixed success setting subdataset and having these return with the correct orientation.
seaice_cdr()
#> [1] "/vsicurl/https://noaadata.apps.nsidc.org/NOAA/G02202_V6/south/daily/2026/sic_pss25_20260728_am2_v06r00.nc"